==> apache-geode-1.12.7-src.tgz: apache-geode-1.12.7-src/geode-serialization/src/main/java/org/apache/geode/internal/serialization/internal/AbstractSerializationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License,
 * Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.serialization.internal;


import org.apache.geode.internal.serialization.Version;
import org.apache.geode.internal.serialization.VersionedDataStream;

/**
 * Both Serialization and Deserialization contexts implement this interface to allow
 * a toData or fromData method to determine the Geode Version of the data stream.
 */
public abstract class AbstractSerializationContext {

  <IO> Version getVersionForDataStream(final IO in) {
    // check if this is a versioned data input
    if (in instanceof VersionedDataStream) {
      final Version v = ((VersionedDataStream) in).getVersion();
      return v != null ? v : Version.getCurrentVersion();
    } else {
      // assume latest version
      return Version.getCurrentVersion();
    }
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-serialization/src/main/java/org/apache/geode/internal/serialization/internal/AbstractSerializationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License,
 * Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.serialization.internal;


import org.apache.geode.internal.serialization.KnownVersion;
import org.apache.geode.internal.serialization.VersionedDataStream;

/**
 * Both Serialization and Deserialization contexts implement this interface to allow
 * a toData or fromData method to determine the Geode Version of the data stream.
 */
public abstract class AbstractSerializationContext {

  <IO> KnownVersion getVersionForDataStream(final IO in) {
    // check if this is a versioned data input
    if (in instanceof VersionedDataStream) {
      final KnownVersion v = ((VersionedDataStream) in).getVersion();
      return v != null ? v : KnownVersion.getCurrentVersion();
    } else {
      // assume latest version
      return KnownVersion.getCurrentVersion();
    }
  }
}
